OrtLoggingLevel enum
Values
- ORT_LOGGING_LEVEL_VERBOSE → const OrtLoggingLevel
-
const OrtLoggingLevel(0) - ORT_LOGGING_LEVEL_INFO → const OrtLoggingLevel
-
const OrtLoggingLevel(1) - ORT_LOGGING_LEVEL_WARNING → const OrtLoggingLevel
-
const OrtLoggingLevel(2) - ORT_LOGGING_LEVEL_ERROR → const OrtLoggingLevel
-
const OrtLoggingLevel(3) - ORT_LOGGING_LEVEL_FATAL → const OrtLoggingLevel
-
const OrtLoggingLevel(4)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → OrtLoggingLevel
Constants
-
values
→ const List<
OrtLoggingLevel> - A constant List of the values in this enum, in order of their declaration.