OrtOpAttrType enum
Values
- ORT_OP_ATTR_UNDEFINED → const OrtOpAttrType
-
const OrtOpAttrType(0) - ORT_OP_ATTR_INT → const OrtOpAttrType
-
const OrtOpAttrType(1) - ORT_OP_ATTR_INTS → const OrtOpAttrType
-
const OrtOpAttrType(2) - ORT_OP_ATTR_FLOAT → const OrtOpAttrType
-
const OrtOpAttrType(3) - ORT_OP_ATTR_FLOATS → const OrtOpAttrType
-
const OrtOpAttrType(4) - ORT_OP_ATTR_STRING → const OrtOpAttrType
-
const OrtOpAttrType(5) - ORT_OP_ATTR_STRINGS → const OrtOpAttrType
-
const OrtOpAttrType(6)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → OrtOpAttrType
Constants
-
values
→ const List<
OrtOpAttrType> - A constant List of the values in this enum, in order of their declaration.