OrtTensorRTProviderOptions class final

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
device_id int
getter/setter pair
has_user_compute_stream int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trt_dla_core int
getter/setter pair
trt_dla_enable int
getter/setter pair
trt_dump_subgraphs int
getter/setter pair
trt_engine_cache_enable int
getter/setter pair
trt_engine_cache_path Pointer<Char>
getter/setter pair
trt_engine_decryption_enable int
getter/setter pair
trt_engine_decryption_lib_path Pointer<Char>
getter/setter pair
trt_force_sequential_engine_build int
getter/setter pair
trt_fp16_enable int
getter/setter pair
trt_int8_calibration_table_name Pointer<Char>
getter/setter pair
trt_int8_enable int
getter/setter pair
trt_int8_use_native_calibration_table int
getter/setter pair
trt_max_partition_iterations int
getter/setter pair
trt_max_workspace_size int
getter/setter pair
trt_min_subgraph_size int
getter/setter pair
user_compute_stream Pointer<Void>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited