OrtCUDAProviderOptions class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - arena_extend_strategy ↔ int
-
getter/setter pair
- cudnn_conv_algo_search → OrtCudnnConvAlgoSearch
-
no setter
- cudnn_conv_algo_searchAsInt ↔ int
-
getter/setter pair
-
default_memory_arena_cfg
↔ Pointer<
OrtArenaCfg> -
getter/setter pair
- device_id ↔ int
-
getter/setter pair
- do_copy_in_default_stream ↔ int
-
getter/setter pair
- gpu_mem_limit ↔ int
-
getter/setter pair
- has_user_compute_stream ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tunable_op_enable ↔ int
-
getter/setter pair
- tunable_op_max_tuning_duration_ms ↔ int
-
getter/setter pair
- tunable_op_tuning_enable ↔ int
-
getter/setter pair
-
user_compute_stream
↔ Pointer<
Void> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited